#line 2 "scan.c"

#line 4 "scan.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 94
#define YY_END_OF_BUFFER 95
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[377] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,   95,   93,
       84,   84,   92,   85,   82,   93,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   94,   94,   94,
       87,   88,   84,   92,   82,   90,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   34,   83,   83,   83,   83,   83,
       83,   83,   83,   44,   83,   83,   83,   49,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,    0,    0,    0,

       87,   86,   90,    3,   83,    5,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   29,   83,   83,   83,
       83,   36,   83,   83,   39,   83,   83,   83,   43,   83,
       46,   47,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   64,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   75,   83,   83,   83,
       83,   83,   80,   91,    0,    0,   89,   83,   83,   83,
       83,   83,   83,   83,   83,    8,   83,   17,   83,   18,
       19,   83,   83,   83,   23,   83,   83,   83,   83,   83,

       83,   31,   83,   83,   35,   83,   38,   83,   41,   42,
       45,   48,   50,   83,   52,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       70,   83,   83,   74,   83,   83,   83,   83,   81,   91,
       91,    4,   83,   83,    9,   83,   83,   83,   83,   83,
       83,   83,   20,   21,   83,   83,   25,   83,   83,   83,
       83,   32,   83,   83,   83,   40,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   65,   66,   83,
       83,   83,   71,   83,   83,   83,   83,   83,    6,    7,
       83,   83,   12,   83,   83,   83,   16,    2,   83,   83,

       83,   27,   28,   83,   83,   83,   37,   51,   83,   83,
       83,   83,   57,   83,   59,   83,   83,   63,   83,   83,
       69,   72,   83,   83,   77,   83,   79,   10,   11,   83,
       83,   83,    2,   22,   83,   83,   30,   83,    1,   53,
       83,   83,   83,   58,   60,   83,   83,   68,   73,   83,
       83,   83,   14,   83,   24,   26,   83,    1,   54,   83,
       56,   61,   83,   83,   83,   13,   15,   33,   55,   62,
       67,   76,   83,   83,   78,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    5,    6,    1,    1,    7,    1,
        1,    1,    1,    1,    1,    1,    1,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    1,    9,   10,
        1,   11,    1,   12,   13,   14,   15,   16,   17,   18,
       19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   37,   22,
        1,    1,    1,    1,   22,    1,   38,   39,   40,   41,

       42,   43,   44,   45,   46,   22,   47,   48,   49,   50,
       51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
       61,   22,    1,    1,    1,    1,    1,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,

       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    2,    3,    3,    1,    4,    5,    4,    1,    1,
        6,    1,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7
    } ;

static yyconst flex_int16_t yy_base[388] =
    {   0,
        0,    0,  155,  147,   61,   73,  136,  106,  111,  876,
       84,   87,    0,  876,  101,    0,   76,   80,   71,   90,
       93,  121,    0,   80,   93,  110,   99,  147,  181,  125,
       79,   97,  221,  156,  140,  102,  128,  876,    0,  178,
        0,   97,  193,    0,   94,    0,    0,  159,  125,  131,
      182,  191,  141,  120,  144,  161,  173,  171,  204,  205,
      228,  218,  183,  231,    0,  244,  211,  231,  245,  237,
      236,  246,  238,  234,  265,  271,  267,  268,  272,  264,
      282,  285,  286,  273,  300,  283,  277,  296,  285,  293,
      307,  309,  311,  318,  306,  316,  314,   86,  348,  357,

        0,  876,    0,    0,  334,    0,  340,  348,  341,  339,
      346,  356,  339,  364,  361,  358,  353,  356,  357,  359,
      371,  356,  365,  361,  376,  375,  385,  374,  386,  390,
      383,    0,  385,  396,    0,  404,  407,  408,    0,  410,
        0,    0,  397,  393,  412,  412,  407,  402,  413,  416,
      427,  410,  424,  420,  418,  421,    0,  445,  434,  436,
      453,  440,  454,  449,  457,  459,    0,  452,  453,  448,
      469,  452,    0,  507,   96,  510,  211,  472,  467,  477,
      473,  474,  475,  474,  502,    0,  486,    0,  495,    0,
        0,  495,  494,  495,    0,  502,  516,  505,  504,  523,

      524,  502,  508,  508,    0,  526,    0,  527,    0,    0,
        0,    0,    0,  525,    0,  534,  530,  533,  536,  539,
      553,  542,  547,  550,  557,  549,  558,  563,  563,  566,
        0,  566,  559,    0,  556,  569,  574,  558,    0,  613,
      876,    0,  567,  564,    0,  576,  576,  593,  578,  590,
      604,  607,    0,    0,  595,  595,    0,  612,  610,  601,
      604,    0,  610,  619,  612,    0,  613,  610,  620,  623,
      609,  614,  615,  616,  636,  628,  629,    0,    0,  635,
      639,  651,  642,  641,  643,  653,  648,  663,    0,    0,
      652,  652,    0,  660,  668,  656,    0,  688,  676,  678,

      676,    0,    0,  686,  677,  690,    0,    0,  693,  696,
      693,  698,    0,  685,    0,  688,  706,    0,  701,  693,
        0,    0,  694,  716,    0,  715,    0,    0,    0,  714,
      706,  704,  749,    0,  706,  720,    0,  716,  761,    0,
      714,  728,  719,    0,    0,  742,  747,    0,    0,  743,
      739,  755,    0,  737,    0,    0,  744,  774,    0,  756,
        0,  748,  763,  758,  762,    0,    0,    0,    0,    0,
        0,    0,  771,  770,    0,  876,  812,  819,  826,  833,
       87,  837,  844,  850,  857,  861,  868
    } ;

static yyconst flex_int16_t yy_def[388] =
    {   0,
      376,    1,  377,  377,  378,  378,  379,  379,  376,  376,
      376,  376,  380,  376,  376,  381,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  376,  383,  384,
      385,  376,  376,  380,  376,  386,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  383,  387,  384,

      385,  376,  386,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  376,  387,  387,  387,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,

      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  376,
      376,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,

      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  376,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  376,  382,  382,
      382,  382,  382,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,    0,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376
    } ;

static yyconst flex_int16_t yy_nxt[938] =
    {   0,
       10,   11,   12,   11,   13,   10,   14,   15,   10,   10,
       10,   16,   17,   18,   19,   20,   21,   22,   23,   23,
       24,   23,   25,   26,   27,   28,   29,   30,   31,   32,
       33,   34,   35,   23,   36,   23,   37,   17,   18,   19,
       20,   21,   22,   23,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   23,   36,   23,
       37,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   43,   43,   43,   43,   43,
       43,   48,   50,   46,   51,   65,  174,   52,  376,   49,

       53,   45,   54,  102,  177,   66,   55,   57,   45,   67,
      376,   82,   42,   83,   96,   70,   48,   50,   51,   56,
       65,   52,   58,   49,   53,   71,   59,   54,   60,   66,
       68,   55,   57,   61,   67,   82,   69,   80,   83,   96,
       70,   62,   42,   56,   97,  107,   58,   63,  106,   71,
       59,  115,   60,   64,   81,   68,   39,  114,   61,   72,
       69,  116,   80,   73,   39,   94,   62,   95,   91,   97,
      107,   63,  106,   74,  104,  115,   92,   64,   81,   99,
       99,   99,  114,  105,   72,   93,  116,  117,   73,   94,
      376,   95,  118,   91,   43,   43,   43,   74,   75,  104,

      119,   92,  108,  376,   76,   77,   78,  105,  109,   93,
       79,  117,  127,  376,  110,  111,  112,  118,  113,  177,
      120,  121,  376,   75,  119,  122,  376,  108,   76,   77,
       78,  376,  109,  376,   79,   84,  127,   85,  110,  111,
      112,  125,  113,  126,   86,  120,  121,  132,  123,  140,
      122,  124,   87,   88,  128,   89,  129,   90,  130,  134,
       84,  133,   85,  135,  131,  125,  136,  126,   86,  137,
      138,  132,  139,  123,  140,  124,   87,   88,  128,   89,
      129,   90,  141,  130,  134,  133,  142,  143,  135,  131,
      136,  144,  145,  137,  138,  146,  139,  149,  147,  158,

      150,  376,  153,  159,  376,  162,  376,  141,  148,  160,
      161,  142,  143,  151,  154,  144,  152,  145,  163,  146,
      164,  171,  149,  147,  158,  150,  153,  159,  155,  156,
      162,  157,  148,  165,  160,  161,  172,  151,  168,  154,
      152,  169,  163,  166,  173,  164,  171,  167,  170,  176,
       99,  176,  155,  156,  178,  157,  177,  165,   99,   99,
       99,  172,  179,  168,  180,  169,  181,  166,  173,  182,
      183,  167,  170,  184,  376,  186,  187,  188,  189,  178,
      190,  185,  191,  192,  193,  194,  179,  195,  196,  180,
      181,  197,  198,  182,  183,  199,  376,  202,  184,  186,

      203,  187,  188,  189,  190,  185,  191,  192,  193,  200,
      194,  195,  196,  204,  205,  197,  206,  198,  207,  201,
      199,  202,  208,  209,  210,  203,  211,  376,  212,  213,
      214,  215,  219,  200,  216,  217,  218,  204,  205,  220,
      206,  221,  207,  201,  222,  376,  223,  208,  209,  210,
      224,  211,  212,  213,  225,  214,  215,  219,  216,  217,
      218,  226,  376,  227,  220,  221,  228,  229,  231,  222,
      223,  230,  232,  233,  224,  234,  376,  235,  225,  236,
      237,  238,  376,  239,  376,  376,  226,  227,  376,  245,
      228,  247,  229,  231,  248,  230,  232,  242,  233,  243,

      234,  235,  244,  236,  237,  246,  238,  239,  240,  240,
      240,  176,   99,  176,  245,  241,  247,  251,  177,  248,
      252,  242,  249,  243,  253,  254,  244,  255,  256,  246,
      258,  250,  257,  376,  259,  260,  261,  376,  262,  263,
      264,  251,  265,  266,  252,  267,  268,  249,  253,  254,
      269,  255,  256,  270,  258,  250,  271,  257,  259,  272,
      260,  261,  262,  263,  264,  273,  276,  265,  266,  274,
      267,  268,  275,  277,  279,  269,  278,  280,  270,  281,
      282,  271,  283,  286,  272,  284,  285,  287,  376,  288,
      273,  276,  291,  274,  289,  290,  275,  376,  277,  279,

      278,  292,  280,  295,  281,  282,  296,  283,  286,  284,
      285,  293,  287,  288,  240,  240,  240,  291,  289,  290,
      297,  241,  294,  298,  301,  292,  299,  295,  300,  302,
      305,  296,  303,  304,  306,  310,  293,  307,  308,  309,
      311,  376,  312,  313,  314,  297,  294,  315,  298,  301,
      299,  316,  300,  317,  302,  305,  303,  304,  318,  306,
      310,  307,  308,  309,  319,  311,  312,  313,  314,  320,
      321,  315,  322,  323,  324,  325,  316,  317,  326,  327,
      376,  328,  318,  329,  330,  331,  376,  332,  319,  333,
      333,  333,  334,  320,  335,  321,  322,  323,  324,  325,

      336,  337,  326,  338,  327,  328,  339,  329,  330,  340,
      331,  332,  341,  342,  343,  376,  344,  334,  345,  335,
      346,  347,  376,  348,  336,  349,  337,  338,  350,  351,
      352,  339,  353,  354,  340,  355,  356,  341,  342,  343,
      344,  357,  345,  359,  360,  346,  347,  348,  361,  349,
      333,  333,  333,  350,  351,  352,  353,  354,  362,  355,
      363,  356,  358,  358,  358,  357,  364,  359,  365,  360,
      366,  369,  361,  367,  368,  358,  358,  358,  370,  371,
      376,  372,  373,  362,  374,  363,  375,  376,  376,  376,
      364,  376,  365,  376,  376,  366,  369,  367,  368,  376,

      376,  376,  370,  376,  371,  372,  376,  373,  376,  374,
      376,  375,   38,   38,   38,   38,   38,   38,   38,   40,
       40,   40,   40,   40,   40,   40,   41,   41,   41,   41,
       41,   41,   41,   44,   44,  376,   44,   44,   44,   44,
       47,  376,  376,   47,   98,   98,   98,   98,   98,  376,
       98,  100,  100,  100,  376,  376,  100,  101,  101,  101,
      101,  376,  101,  101,  103,  376,  376,  103,  175,  175,
      175,  175,  175,  175,  175,    9,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,

      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376
    } ;

static yyconst flex_int16_t yy_chk[938] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,   11,   11,   11,   12,   12,
       12,   17,   18,  381,   19,   24,   98,   19,  175,   17,

       19,   45,   20,   42,  175,   24,   20,   21,   15,   25,
        9,   31,    8,   32,   36,   27,   17,   18,   19,   20,
       24,   19,   21,   17,   19,   27,   21,   20,   21,   24,
       26,   20,   21,   22,   25,   31,   26,   30,   32,   36,
       27,   22,    7,   20,   37,   50,   21,   22,   49,   27,
       21,   54,   21,   22,   30,   26,    4,   53,   22,   28,
       26,   55,   30,   28,    3,   35,   22,   35,   34,   37,
       50,   22,   49,   28,   48,   54,   34,   22,   30,   40,
       40,   40,   53,   48,   28,   34,   55,   56,   28,   35,
        0,   35,   57,   34,   43,   43,   43,   28,   29,   48,

       58,   34,   51,    0,   29,   29,   29,   48,   51,   34,
       29,   56,   63,  177,   51,   52,   52,   57,   52,  177,
       59,   60,    0,   29,   58,   60,    0,   51,   29,   29,
       29,    0,   51,    0,   29,   33,   63,   33,   51,   52,
       52,   62,   52,   62,   33,   59,   60,   67,   61,   74,
       60,   61,   33,   33,   64,   33,   64,   33,   66,   69,
       33,   68,   33,   69,   66,   62,   70,   62,   33,   71,
       72,   67,   73,   61,   74,   61,   33,   33,   64,   33,
       64,   33,   75,   66,   69,   68,   76,   77,   69,   66,
       70,   78,   79,   71,   72,   80,   73,   82,   81,   86,

       83,    0,   84,   87,    0,   89,    0,   75,   81,   88,
       88,   76,   77,   83,   85,   78,   83,   79,   90,   80,
       91,   95,   82,   81,   86,   83,   84,   87,   85,   85,
       89,   85,   81,   92,   88,   88,   96,   83,   94,   85,
       83,   94,   90,   93,   97,   91,   95,   93,   94,   99,
       99,   99,   85,   85,  105,   85,   99,   92,  100,  100,
      100,   96,  107,   94,  108,   94,  109,   93,   97,  110,
      111,   93,   94,  112,    0,  113,  114,  115,  116,  105,
      117,  112,  118,  119,  120,  121,  107,  122,  123,  108,
      109,  124,  125,  110,  111,  126,    0,  128,  112,  113,

      129,  114,  115,  116,  117,  112,  118,  119,  120,  127,
      121,  122,  123,  130,  131,  124,  133,  125,  134,  127,
      126,  128,  136,  137,  138,  129,  140,    0,  143,  144,
      145,  146,  150,  127,  147,  148,  149,  130,  131,  151,
      133,  152,  134,  127,  153,    0,  154,  136,  137,  138,
      155,  140,  143,  144,  156,  145,  146,  150,  147,  148,
      149,  158,    0,  159,  151,  152,  160,  161,  163,  153,
      154,  162,  164,  165,  155,  166,    0,  168,  156,  169,
      170,  171,    0,  172,    0,    0,  158,  159,    0,  181,
      160,  183,  161,  163,  184,  162,  164,  178,  165,  179,

      166,  168,  180,  169,  170,  182,  171,  172,  174,  174,
      174,  176,  176,  176,  181,  174,  183,  187,  176,  184,
      189,  178,  185,  179,  192,  193,  180,  194,  196,  182,
      198,  185,  197,    0,  199,  200,  201,    0,  202,  203,
      204,  187,  206,  208,  189,  214,  216,  185,  192,  193,
      217,  194,  196,  218,  198,  185,  219,  197,  199,  220,
      200,  201,  202,  203,  204,  221,  224,  206,  208,  222,
      214,  216,  223,  225,  227,  217,  226,  228,  218,  229,
      230,  219,  232,  236,  220,  233,  235,  237,    0,  238,
      221,  224,  246,  222,  243,  244,  223,    0,  225,  227,

      226,  247,  228,  249,  229,  230,  250,  232,  236,  233,
      235,  248,  237,  238,  240,  240,  240,  246,  243,  244,
      251,  240,  248,  252,  258,  247,  255,  249,  256,  259,
      263,  250,  260,  261,  264,  269,  248,  265,  267,  268,
      270,    0,  271,  272,  273,  251,  248,  274,  252,  258,
      255,  275,  256,  276,  259,  263,  260,  261,  277,  264,
      269,  265,  267,  268,  280,  270,  271,  272,  273,  281,
      282,  274,  283,  284,  285,  286,  275,  276,  287,  288,
        0,  291,  277,  292,  294,  295,    0,  296,  280,  298,
      298,  298,  299,  281,  300,  282,  283,  284,  285,  286,

      301,  304,  287,  305,  288,  291,  306,  292,  294,  309,
      295,  296,  310,  311,  312,    0,  314,  299,  316,  300,
      317,  319,    0,  320,  301,  323,  304,  305,  324,  326,
      330,  306,  331,  332,  309,  335,  336,  310,  311,  312,
      314,  338,  316,  341,  342,  317,  319,  320,  343,  323,
      333,  333,  333,  324,  326,  330,  331,  332,  346,  335,
      347,  336,  339,  339,  339,  338,  350,  341,  351,  342,
      352,  360,  343,  354,  357,  358,  358,  358,  362,  363,
        0,  364,  365,  346,  373,  347,  374,    0,    0,    0,
      350,    0,  351,    0,    0,  352,  360,  354,  357,    0,

        0,    0,  362,    0,  363,  364,    0,  365,    0,  373,
        0,  374,  377,  377,  377,  377,  377,  377,  377,  378,
      378,  378,  378,  378,  378,  378,  379,  379,  379,  379,
      379,  379,  379,  380,  380,    0,  380,  380,  380,  380,
      382,    0,    0,  382,  383,  383,  383,  383,  383,    0,
      383,  384,  384,  384,    0,    0,  384,  385,  385,  385,
      385,    0,  385,  385,  386,    0,    0,  386,  387,  387,
      387,  387,  387,  387,  387,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,

      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[95] =
    {   0,
1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 0, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scan.l"
#line 2 "scan.l"
/*-------------------------------------------------------------------------
 * scan.l
 *
 *	Flex keyword and token scanner for slonik
 *
 *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 *	Author: Jan Wieck, Afilias USA INC.
 *
 *	
 *-------------------------------------------------------------------------
 */
struct __yy_buffer
{
	YY_BUFFER_STATE	     buffer;				/* lexer buffer to restore on pop	*/
	long		         lineno;				/* line number to restore on pop	*/
	char               * fileName;				/* file name to restore on pop		*/
	struct __yy_buffer * prev;					/* pointer to previous stack frame	*/
} * yy_buffer = NULL;

typedef struct _symbol
{
    char           * name;						/* Name of symbol with % prepended	*/
	char           * value;						/* Value of symbol					*/
	struct _symbol * next;						/* Pointer to next symbol			*/
} symbol;

static symbol * symbols;						/* Head of list of symbols			*/

static char * getSymbol( const char * name );	/* Return a symbol's value (or NULL)*/
static void   addSymbol( char * str );			/* Add a new symbol					*/
static void   freeSymbols( void );              /* Free all symbols                 */
static void   pushBuffer( char * context );		/* Push a new lexer buffer on stack */
static void   popBuffer( void );				/* Pop previous lexer buffer		*/

extern char * current_file;
#line 40 "scan.l"

#include "libpq-fe.h"
#include "slonik.h"
#include "y.tab.h"


/*
quoted_ident	(\"[^\"]*\")+
identifier		({ident_start}{ident_cont}*|{quoted_ident})
*/
#line 863 "scan.c"

#define INITIAL 0
#define incl 1
#define define 2
#define IN_STRING 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 67 "scan.l"


	char   *instring_buffer = NULL;
	int     instring_length=0;
	int     instring_buf_length=0;

	BEGIN(INITIAL);

#line 1060 "scan.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 377 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 876 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 75 "scan.l"
{ BEGIN(incl); }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 76 "scan.l"
{ BEGIN(define); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 78 "scan.l"
{ return K_ADD;				}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 79 "scan.l"
{ return K_ADMIN;			}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 80 "scan.l"
{ return K_ALL;				}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 81 "scan.l"
{ return K_BACKUP;			}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 82 "scan.l"
{ return K_CLIENT;			}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 83 "scan.l"
{ return K_COPY;			}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 84 "scan.l"
{ return K_CLONE;			}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 85 "scan.l"
{ return K_CLUSTER;			}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 86 "scan.l"
{ return K_COMMENT;			}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 87 "scan.l"
{ return K_CONFIG;			}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 88 "scan.l"
{ return K_CONFIRMED;		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 89 "scan.l"
{ return K_CONNINFO;		}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 90 "scan.l"
{ return K_CONNRETRY;		}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 91 "scan.l"
{ return K_CREATE;			}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 92 "scan.l"
{ return K_DATE;			}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 93 "scan.l"
{ return K_DROP;			}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 94 "scan.l"
{ return K_ECHO;			}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 95 "scan.l"
{ return K_ERROR;			}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 96 "scan.l"
{ return K_EVENT;			}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 97 "scan.l"
{ return K_EXECUTE;			}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 98 "scan.l"
{ return K_EXIT;			}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 99 "scan.l"
{ return K_FAILOVER;		}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 100 "scan.l"
{ return K_FALSE;			}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 101 "scan.l"
{ return K_FILENAME;		}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 102 "scan.l"
{ return K_FINISH;			}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 103 "scan.l"
{ return K_DFORMAT;			}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 104 "scan.l"
{ return K_FOR;				}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 105 "scan.l"
{ return K_FORWARD;			}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 106 "scan.l"
{ return K_FULL;			}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 107 "scan.l"
{ return K_FULL;			}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 108 "scan.l"
{ return K_FUNCTIONS;		}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 109 "scan.l"
{ return K_ID;				}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 110 "scan.l"
{ return K_INIT;			}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 111 "scan.l"
{ return K_KEY;				}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 112 "scan.l"
{ return K_LISTEN;			}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 113 "scan.l"
{ return K_LOCK;			}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 114 "scan.l"
{ return K_LOG;				}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 115 "scan.l"
{ return K_MERGE;			}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 116 "scan.l"
{ return K_MOVE;			}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 117 "scan.l"
{ return K_NAME;			}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 118 "scan.l"
{ return K_NEW;				}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 119 "scan.l"
{ return K_NO;				}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 120 "scan.l"
{ return K_NODE;			}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 121 "scan.l"
{ return K_OFF;				}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 122 "scan.l"
{ return K_OLD;				}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 123 "scan.l"
{ return K_OMIT;				}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 124 "scan.l"
{ return K_ON;				}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 125 "scan.l"
{ return K_ONLY;			}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 126 "scan.l"
{ return K_ORIGIN;			}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 127 "scan.l"
{ return K_PATH;			}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 128 "scan.l"
{ return K_PREPARE;			}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 129 "scan.l"
{ return K_PROVIDER;		}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 130 "scan.l"
{ return K_QUALIFIED;		}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 131 "scan.l"
{ return K_RECEIVER;		}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 132 "scan.l"
{ return K_REPAIR;			}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 133 "scan.l"
{ return K_RESTART;			}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 134 "scan.l"
{ return K_SCRIPT;			}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 135 "scan.l"
{ return K_SECONDS;         }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 136 "scan.l"
{ return K_SEQUENCE;		}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 137 "scan.l"
{ return K_SEQUENCES;		}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 138 "scan.l"
{ return K_SERVER;			}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 139 "scan.l"
{ return K_SET;				}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 140 "scan.l"
{ return K_SLEEP;			}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 141 "scan.l"
{ return K_STORE;			}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 142 "scan.l"
{ return K_SUBSCRIBE;		}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 143 "scan.l"
{ return K_SUCCESS;			}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 144 "scan.l"
{ return K_SWITCH;			}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 145 "scan.l"
{ return K_SYNC;			}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 146 "scan.l"
{ return K_TABLE;			}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 147 "scan.l"
{ return K_TABLES;			}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 148 "scan.l"
{ return K_TIMEOUT;			}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 149 "scan.l"
{ return K_TRUE;			}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 150 "scan.l"
{ return K_TRY;				}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 151 "scan.l"
{ return K_UNINSTALL;		}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 152 "scan.l"
{ return K_UNLOCK;			}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 153 "scan.l"
{ return K_UNSUBSCRIBE;		}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 154 "scan.l"
{ return K_UPDATE;			}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 155 "scan.l"
{ return K_YES;				}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 156 "scan.l"
{ return K_WAIT;			}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 158 "scan.l"
{ return T_NUMBER;			}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 159 "scan.l"
{ return T_IDENT;			}
	YY_BREAK
case 84:
/* rule 84 can match eol */
YY_RULE_SETUP
#line 161 "scan.l"
;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 163 "scan.l"
{ 
			if( instring_buffer==NULL )
			{
				instring_buffer=malloc(256);
				if( instring_buffer == NULL)
				{
						fprintf(stderr,"insufficient memory\n");
						exit(1);


				}		
				instring_buf_length=256;
			}
			instring_length=0;
			instring_buffer[instring_length]=*yytext;
			BEGIN(IN_STRING);
		}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 180 "scan.l"

	YY_BREAK
case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
#line 181 "scan.l"
{ 
				if (  instring_buf_length < instring_length + yyleng+1 )
				{
						instring_buffer=realloc(instring_buffer,instring_buf_length*2);
						instring_buf_length=instring_buf_length*2;
				}
				strncpy(instring_buffer+instring_length,yytext,yyleng);
				instring_length+=yyleng;

				
		}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 192 "scan.l"
{
			instring_buffer[instring_length]='\0';
			yytext = instring_buffer;
			yyleng=instring_length;

			BEGIN(INITIAL);
			return T_LITERAL;
		}
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 200 "scan.l"
{ addSymbol( yytext ); BEGIN(INITIAL); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 202 "scan.l"
{ 
                  char * value = getSymbol( yytext );
                  
                  if( value )
                  {
                    pushBuffer( strdup( current_file ));
                    yy_scan_string(value );
                  }
                }
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 212 "scan.l"
{

                    char * fileName = strdup( yytext + 1 ); /* Skip '<' */

                    *strchr( fileName, '>' ) = '\0';        /* Trim '>' */

                    pushBuffer( fileName );

                    if(( yyin = fopen( fileName, "r" )) == NULL )
                    {
                        fprintf( stderr,  "Include file (%s) not found\n", fileName );
                        exit( 1 );
                    }
                 
                    yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE ));

                    BEGIN(INITIAL);
                }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(incl):
case YY_STATE_EOF(define):
case YY_STATE_EOF(IN_STRING):
#line 231 "scan.l"
{
                    if( yy_buffer == NULL )
                        yyterminate();
                    else
                        popBuffer();
                }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 238 "scan.l"
;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 240 "scan.l"
{ return yytext[0];				}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 242 "scan.l"
ECHO;
	YY_BREAK
#line 1699 "scan.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 377 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 377 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 376);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 242 "scan.l"



void
scan_new_input_file(FILE *in)
{
	SlonDString		ds;
	char			buf[8192];
	int				len;

	if (YY_CURRENT_BUFFER)
		yy_delete_buffer(YY_CURRENT_BUFFER);

	dstring_init(&ds);
	while ((len = fread(&buf, 1, 8192, in)) > 0)
	{
		dstring_nappend(&ds, buf, len);
	}
	dstring_terminate(&ds);
	yy_switch_to_buffer(yy_scan_string(dstring_data(&ds)));

	dstring_free(&ds);

    freeSymbols();
}

static void pushBuffer( char * context )
{
	struct __yy_buffer * yb = malloc( sizeof( *yb ));

	yb->buffer   = YY_CURRENT_BUFFER;
	yb->lineno   = yylineno;
	yb->fileName = strdup( current_file );
	yb->prev     = yy_buffer;

	yy_buffer = yb;

	current_file = context;
	yylineno     = 1;
}

static void popBuffer( void )
{
	struct __yy_buffer * yb = yy_buffer;

	if( yyin != NULL )
		fclose( yyin );
	
	yy_delete_buffer(YY_CURRENT_BUFFER );
	yy_switch_to_buffer(yy_buffer->buffer );
	
	free( current_file );
	
	current_file = yy_buffer->fileName;
	yylineno     = yy_buffer->lineno;
	
	yy_buffer = yy_buffer->prev;
	
	free( yb );
}

static void addSymbol( char * str )
{
	char   * name  = str;
	char   * value = str;
	symbol * sym   = NULL;

	while( *value != ' ' && *value != '\t' )
		value++;

	*(value++) = '\0';

	while( *value == ' ' || *value == '\t' )
		value++;

	value[strlen(value) - 1 ] = '\0';

	sym = malloc( sizeof( *sym ));
	sym->value = strdup( value );
	sym->next  = NULL;
	
	/* Store the symbol name in searchable form  with a leading @ */

	sym->name  = malloc( strlen( name ) + 1 + 1 );

	sym->name[0] = '@';
	strcpy( sym->name+1, name );

	if( symbols != NULL )
		sym->next = symbols;

	symbols = sym;
}

static char * getSymbol( const char * name )
{
	symbol * sym;

	for( sym = symbols; sym; sym = sym->next )
	{
		if( strcmp( name, sym->name ) == 0 )
			return( sym->value );
	}

	return( NULL );
}

static void freeSymbols( void )
{
	symbol * sym = symbols;

	while( sym )
	{
		symbol * victim = sym;

		sym = sym->next;

		free( victim->name );
		free( victim->value );
		free( victim );
	}

	symbols = NULL;
}
/*
 * Local Variables:
 *  tab-width: 4
 *  c-indent-level: 4
 *  c-basic-offset: 4
 * End:
 */

